pub struct CommandInfo {
pub name: String,
pub about: String,
pub subcommands: Vec<CommandInfo>,
pub args: Vec<ArgInfo>,
}Expand description
Declarative description of a command (and its subcommands/args) that a plugin exposes. The host rebuilds clap commands from this over the wire.
Fields
name: Stringabout: Stringsubcommands: Vec<CommandInfo>args: Vec<ArgInfo>Implementations
Sourceimpl CommandInfo
impl CommandInfo
Sourcepub fn new(name: impl Into<String>, about: impl Into<String>) -> CommandInfo
pub fn new(name: impl Into<String>, about: impl Into<String>) -> CommandInfo
Create a leaf command with no args or subcommands.
Sourcepub fn arg(self, arg: ArgInfo) -> CommandInfo
pub fn arg(self, arg: ArgInfo) -> CommandInfo
Add a positional/required argument (builder style).
Sourcepub fn subcommand(self, sub: CommandInfo) -> CommandInfo
pub fn subcommand(self, sub: CommandInfo) -> CommandInfo
Add a nested subcommand (builder style).